@@ -3,7 +3,7 @@ from django.forms import widgets
 from django.conf import settings
 
 class ImageUploaderWidget(widgets.ClearableFileInput):
-    template_name = 'widgets/image_uploader_widget.html'
+    template_name = 'admin/widgets/image_uploader_widget.html'
     non_file_text = ''
 
     def __init__(self, non_file_text = 'Click here to select a file!', attrs = None):
@@ -20,13 +20,11 @@ class ImageUploaderWidget(widgets.ClearableFileInput):
         extra = '' if settings.DEBUG else '.min'
         return forms.Media(
             js=(
-                'admin/js/vendor/jquery/jquery%s.js' % extra,
-                'admin/js/jquery.init.js',
-                'widgets/image_uploader_widget.js',
+                'admin/js/image-uploader%s.js' % extra,
             ),
             css={
                 'screen': (
-                    'widgets/image_uploader_widget.css',
+                    'admin/css/image-uploader%s.css' % extra,
                 ),
             },
         )
